@@ -24,6 +24,6 @@
 ## Created: 2015-04-18
 
 function d = _com ()
-## See IEEE Std 1788-2015 14.4 Interchange representations and encodings
-persistent d = uint8 (16);
+  ## See IEEE Std 1788-2015 14.4 Interchange representations and encodings
+  d = uint8 (16);
 endfunction
